@@ -4,8 +4,8 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "isotopeparser.h"
 #include "isotope.h"
+#include "isotopeparser.h"
 #include <QDebug>
 #include <iostream>
 
@@ -16,7 +16,7 @@ int main(int argc, char *argv[])
         return 1;
     }
 
-    IsotopeParser * parser = new IsotopeParser();
+    auto parser = new IsotopeParser();
     QFile xmlFile(argv[1]);
 
     QXmlInputSource source(&xmlFile);
@@ -25,21 +25,22 @@ int main(int argc, char *argv[])
     reader.setContentHandler(parser);
     reader.parse(source);
 
-    QList<Isotope*> v = parser->getIsotopes();
+    const QList<Isotope *> v = parser->getIsotopes();
 
-    qDebug() << "Found " << v.count() << " isotopes.";;
+    qDebug() << "Found " << v.count() << " isotopes.";
+    ;
 
     qDebug() << "As a test I am now issuing all isotopes with 50 nuclueons: ";
 
-    foreach (Isotope* i, v) {
+    for (Isotope *i : v) {
         if (i) {
-//X             if (i->nucleons() == 50 ) {
-//X                 qDebug() << "   Isotope of " << i->parentElementSymbol() << " with a mass of " << i->mass();
-//X                 qDebug() << "       Halflife: " << i->halflife() << i->halflifeUnit( );
-//X             }
+            // X             if (i->nucleons() == 50 ) {
+            // X                 qDebug() << "   Isotope of " << i->parentElementSymbol() << " with a mass of " << i->mass();
+            // X                 qDebug() << "       Halflife: " << i->halflife() << i->halflifeUnit( );
+            // X             }
             if (i->parentElementSymbol() == QLatin1String("Ti")) {
                 qDebug() << "   Isotope of " << i->parentElementSymbol() << " with a mass of " << i->mass();
-                qDebug() << "       Halflife: " << i->halflife() << i->halflifeUnit( );
+                qDebug() << "       Halflife: " << i->halflife() << i->halflifeUnit();
             }
         }
     }
