@@ -32,8 +32,8 @@ class titrationCalculator : public QWidget
     Q_OBJECT
 
 public:
-    explicit titrationCalculator(QWidget * parent = nullptr);
-    ~titrationCalculator();
+    explicit titrationCalculator(QWidget *parent = nullptr);
+    ~titrationCalculator() override;
 
 public Q_SLOTS:
     void on_pushButton_clicked();
@@ -68,7 +68,7 @@ private:
     QString greenplot;
     QString blueplot;
 
-    Ui::titrationCalculator uid;               // The user interface
+    Ui::titrationCalculator uid; // The user interface
 };
 
 #endif // TITRATIONCALCULATOR_H
