@@ -6,14 +6,14 @@
 #ifndef KALZIUM_H
 #define KALZIUM_H
 
-#include <kxmlguiwindow.h>
-#include "periodictableview.h"
-#include "unitsettingsdialog.h"
-#include "isotopetabledialog.h"
-#include "elementdataviewer.h"
-#include "tablesdialog.h"
-#include "rsdialog.h"
 #include "calculator/calculator.h"
+#include "elementdataviewer.h"
+#include "isotopetabledialog.h"
+#include "periodictableview.h"
+#include "rsdialog.h"
+#include "settings/kalziumconfigdialog.h"
+#include "tablesdialog.h"
+#include <kxmlguiwindow.h>
 
 class KAction;
 class KSelectAction;
@@ -127,7 +127,7 @@ private:
 
     ExportDialog *m_exportDialog;
 
-    UnitSettingsDialog *m_unitsDialog;
+    KalziumConfigDialog *m_configDialog;
 
     QLabel *m_elementInfo;
 
