@@ -29,12 +29,12 @@ private:
     int Elemno;
 
     /// Label that shows the electronic configuration
-    QLabel *m_electronConf;
+    QLabel *const m_electronConf;
 
     QList<int> numOfElectrons;
 
 protected Q_SLOTS:
-    virtual void paintEvent(QPaintEvent*) override;
+    virtual void paintEvent(QPaintEvent *) override;
 };
 
 #endif // ORBITSWIDGET_H
